@@ -19,6 +19,7 @@ static int error_handler_called = 0;
 
 static void error_handler(int priority, const char *format, va_list args)
 {
+	ARG_NOT_USED(args);
 	if (!strcmp(format, MSG)) {
 		gdTestAssertMsg(priority == GD_WARNING, "expected priority %d, but got %d", GD_WARNING, priority);
 		error_handler_called = 1;
@@ -34,6 +35,10 @@ int main()
 
 	im = gdImageCreateTrueColor(10, 10);
 	fp = gdTestTempFp();
+	gdTestAssert(fp != NULL);
+	if (!fp) {
+		exit(2);
+	}
 	gdImagePngEx(im, fp, 100);
 	gdImageDestroy(im);
 	fclose(fp);
